"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NumberedStyles = void 0;
var NumberedStyles = /** @class */ (function () {
    function NumberedStyles(styles, regex, pressFunctions) {
        this.styles = styles;
        this.regex = regex;
        this.pressFunctions = pressFunctions;
    }
    NumberedStyles.prototype.validate = function (text) {
        var stylesIsArray = Array.isArray(this.styles);
        if (!stylesIsArray)
            return false;
        var _a = this.regex, TEXT_AMONG_BRACKETS = _a.TEXT_AMONG_BRACKETS, TEXT_WITH_BRACKETS = _a.TEXT_WITH_BRACKETS, KEY_VALUE_NUMBER = _a.KEY_VALUE_NUMBER;
        var textIsHighlighted = TEXT_WITH_BRACKETS.test(text);
        if (!textIsHighlighted)
            return false;
        var textIsKeyValue = text.split(TEXT_AMONG_BRACKETS).some(function (t) {
            var textIsKeyValueNumber = KEY_VALUE_NUMBER.test(t);
            return textIsKeyValueNumber;
        });
        return textIsKeyValue;
    };
    NumberedStyles.prototype.create = function (text) {
        var TEXT_AMONG_BRACKETS = this.regex.TEXT_AMONG_BRACKETS;
        var pureText = text.replace(TEXT_AMONG_BRACKETS, '$1');
        var _a = this.getProperties(pureText), finalText = _a[0], styles = _a[1], onPress = _a[2];
        return {
            text: finalText,
            styles: styles,
            onPress: onPress,
        };
    };
    NumberedStyles.prototype.getProperties = function (value) {
        var _this = this;
        var _a = value.split('='), key = _a[0], text = _a[1];
        var keys = key
            .split(',')
            .map(function (stringNumbers) { return parseInt(stringNumbers) - 1; });
        var styles = keys.map(function (key) { return _this.styles[key]; });
        var onPress = this.getOnPress(keys);
        return [text, styles, onPress];
    };
    NumberedStyles.prototype.getOnPress = function (keys) {
        var _this = this;
        var _a;
        var key = keys.find(function (value) { var _a; return ((_a = _this.pressFunctions) === null || _a === void 0 ? void 0 : _a[value]) !== undefined; });
        var onPress = key !== undefined
            ? (_a = this.pressFunctions) === null || _a === void 0 ? void 0 : _a[key] : undefined;
        return onPress;
    };
    return NumberedStyles;
}());
exports.NumberedStyles = NumberedStyles;
